@@ -1,18 +1,19 @@
 import cv2
 import numpy as np
 from gabriel_protocol import gabriel_pb2
-from gabriel_client.server_comm import ProducerWrapper
+from gabriel_client.websocket_client import ProducerWrapper
 import logging
 
+
 logger = logging.getLogger(__name__)
 
 
 class OpencvAdapter:
     def __init__(self, preprocess, produce_extras, consume_frame,
-                 video_capture, filter_passed):
+                 video_capture, source_name):
         '''
-        preprocess should take a one frame parameter
-        produce_engine_fields should take no parameters
+        preprocess should take one frame parameter
+        produce_engine_fields takes no parameters
         consume_frame should take one frame parameter and one engine_fields
         parameter
         '''
@@ -21,7 +22,7 @@ class OpencvAdapter:
         self._produce_extras = produce_extras
         self._consume_frame = consume_frame
         self._video_capture = video_capture
-        self._filter_passed = filter_passed
+        self._source_name = source_name
 
     def get_producer_wrappers(self):
         async def producer():
@@ -30,37 +31,32 @@ class OpencvAdapter:
                 return None
 
             frame = self._preprocess(frame)
-            _, jpeg_frame=cv2.imencode('.jpg', frame)
+            _, jpeg_frame = cv2.imencode('.jpg', frame)
 
-            from_client = gabriel_pb2.FromClient()
-            from_client.payload_type = gabriel_pb2.PayloadType.IMAGE
-            from_client.filter_passed = self._filter_passed
-            from_client.payloads_for_frame.append(jpeg_frame.tostring())
+            input_frame = gabriel_pb2.InputFrame()
+            input_frame.payload_type = gabriel_pb2.PayloadType.IMAGE
+            input_frame.payloads.append(jpeg_frame.tostring())
 
             extras = self._produce_extras()
             if extras is not None:
-                from_client.extras.Pack(extras)
+                input_frame.extras.Pack(extras)
 
-            return from_client
+            return input_frame
 
         return [
-            ProducerWrapper(producer=producer, filter_name=self._filter_passed)
+            ProducerWrapper(producer=producer, source_name=self._source_name)
         ]
 
     def consumer(self, result_wrapper):
-        if result_wrapper.filter_passed != self._filter_passed:
-            logger.error('Got result that passed filter %s',
-                         result_wrapper.filter_passed)
-            return
-
         if len(result_wrapper.results) != 1:
-            logger.error('Got %d results in output',
+            logger.error('Got %d results from server',
                          len(result_wrapper.results))
             return
 
         result = result_wrapper.results[0]
         if result.payload_type != gabriel_pb2.PayloadType.IMAGE:
-            logger.error('Got result of type %s', result.payload_type.name)
+            type_name = gabriel_pb2.PayloadType.Name(result.payload_type)
+            logger.error('Got result of type %s', type_name)
             return
 
         np_data = np.fromstring(result.payload, dtype=np.uint8)
